@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import re
 import enum
 import typing
 import asyncio
@@ -72,8 +73,8 @@ class SerialPort(click.ParamType):
         if path.exists():
             return value
 
-        # Windows COM port
-        if value.startswith("COM") and value[3:].isdigit():
+        # Windows COM port (COM10+ uses a different syntax)
+        if re.match(r"^COM[0-9]$|\\\\\.\\COM[0-9]+$", str(path)):
             return value
 
         # Socket URI
@@ -183,6 +184,8 @@ async def flash(
 
     if flasher.app_type == ApplicationType.EZSP:
         running_image_type = FirmwareImageType.NCP_UART_HW
+    elif flasher.app_type == ApplicationType.GECKO_BOOTLOADER:
+        running_image_type = None
     else:
         # TODO: how do you distinguish RCP_UART_802154 from ZIGBEE_NCP_RCP_UART_802154?
         running_image_type = FirmwareImageType.ZIGBEE_NCP_RCP_UART_802154
@@ -190,7 +193,9 @@ async def flash(
     # Ensure the firmware versions and image types are consistent
     if not force and flasher.app_version is not None and metadata is not None:
         is_cross_flashing = (
-            metadata.fw_type is not None and metadata.fw_type != running_image_type
+            metadata.fw_type is not None
+            and running_image_type is not None
+            and metadata.fw_type != running_image_type
         )
 
         if is_cross_flashing and not allow_cross_flashing:
